#ifndef SELECTFROMLISTWINDOW_H
#define SELECTFROMLISTWINDOW_H

#include "controls/dialogwindow.h"
#include <QCheckBox>
namespace Ui {
class SelectFromListWindow;
}

class SelectFromListWindow : public DialogWindow
{
    Q_OBJECT
    
public:
    explicit SelectFromListWindow(QWidget *parent = 0, QString title="",
                                  QString message="", QStringList elements=QStringList(),
                                  int number=0);
    ~SelectFromListWindow();
    
    QStringList GetSelected();

private:
    Ui::SelectFromListWindow *ui;

    int m_Selected;
    int m_Number;
    QStringList m_Elements;
    QList<QCheckBox*> m_CheckButtons;

    void ShowData();

private slots:
    void SelectSlot(bool selected);
};

#endif // SELECTFROMLISTWINDOW_H
